DatasourceGenerator class

Constructors

DatasourceGenerator(String projectName)

Properties

hashCode int
The hash code for this object.
no setterinherited
inlineSchemas Map<String, Map<String, dynamic>>
no setter
projectName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedImports Set<String>
no setter

Methods

generatorDataSource(Map<String, dynamic> paths, String? baseUrl, Map<String, dynamic> components, SwaggerParser parser, String featureName) String
isSdkImport(String name) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetImports() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited