InjectorGenerator class

Constructors

InjectorGenerator(String packageName)

Properties

hashCode int
The hash code for this object.
no setterinherited
packageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateFeatureInjector({required String featureName, required List<String> classes}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited