ModelGenerator class
Constructors
-
ModelGenerator({required Set<
String> generatedEntities})
Properties
-
generatedEntities
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
usedImports
→ Set<
String> -
no setter
Methods
-
entityExists(
String entityName) → bool -
generateClass(
String name, Map< String, dynamic> schema) → String -
generateWithImports(
String schemaName, Map< String, dynamic> schema, String featureName, String projectName) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited