ProviderGenerator class

Constructors

ProviderGenerator(String projectName)

Properties

hashCode int
The hash code for this object.
no setterinherited
projectName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String featureName, required String usecaseName, required String methodName, required List<ProviderParam> params, required String returnType}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited