RepositoryImplGenerator class
Constructors
- RepositoryImplGenerator(String projectName)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateRepositoryImpl(
String className, Map< String, dynamic> paths, Map<String, dynamic> components, String featureName) → String -
isDartSdkType(
String type) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited