SwaggerParser class

Constructors

SwaggerParser(Map<String, dynamic> swagger)
SwaggerParser.fromFile(String path)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swagger Map<String, dynamic>
final

Methods

extractInlineResponseSchemas() Map<String, dynamic>
getBaseUrl() String?
getComponents() Map<String, dynamic>
getPaths() Map<String, dynamic>
getSchemas() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
useSecurity({required Map pathItem, required String method}) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromUrl(String url) Future<SwaggerParser>