UseCaseGenerator class
Constructors
- UseCaseGenerator(String projectName)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
{required String featureName, required String repositoryName, required String methodName, required String returnType, required List< String> parameters, required Set<String> usedEntities, required bool needsFile}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited